#!/bin/bash
set -e
set -x
vmname='VHDBUG'
rootdir="${HOME}/VirtualBox VMs/${vmname}"

# The bug doesn't happen when this line is commented.
wait='true'

# Abort if there is a VBoxSVC process already running
killall -0 -v VBoxSVC && exit 1 || true

mkdir -pv "${rootdir}"

VBoxManage createmedium disk --filename "${rootdir}/basedisk.vhd" --size 1024 --format VHD
test -z "${wait}" || killall -0 -w VBoxSVC

VBoxManage internalcommands dumphdinfo "${rootdir}/basedisk.vhd"
VBoxManage createmedium disk --filename "${rootdir}/diffdisk.vhd" --diffparent "${rootdir}/basedisk.vhd"
test -z "${wait}" || killall -0 -w VBoxSVC

VBoxManage internalcommands dumphdinfo "${rootdir}/diffdisk.vhd"
VBoxManage createmedium disk --filename "${rootdir}/diffdiffdisk.vhd" --diffparent "${rootdir}/diffdisk.vhd"
test -z "${wait}" || killall -0 -w VBoxSVC

VBoxManage internalcommands dumphdinfo "${rootdir}/diffdiffdisk.vhd"
VBoxManage createvm --name "${vmname}" --basefolder "${rootdir}" --ostype Other_64 --register
VBoxManage storagectl "${vmname}" --name SATA --add sata --portcount 4
VBoxManage storageattach "${vmname}" --storagectl SATA --port 0 --type hdd --medium "${rootdir}/diffdiffdisk.vhd"
test -z "${wait}" || killall -0 -w VBoxSVC

VBoxManage showvminfo "${vmname}"
test -z "${wait}" || killall -0 -w VBoxSVC

VBoxManage unregistervm "${vmname}" --delete
test -f "${rootdir}/diffdiffdisk.vhd" && VBoxManage closemedium disk "${rootdir}/diffdiffdisk.vhd" --delete || true
test -f "${rootdir}/diffdisk.vhd" && VBoxManage closemedium disk "${rootdir}/diffdisk.vhd" --delete || true
test -f "${rootdir}/basedisk.vhd" && VBoxManage closemedium disk "${rootdir}/basedisk.vhd" --delete || true
killall -0 -w VBoxSVC || true

echo 'Test ended successfully'
